<?php

require_once 'base/FpaCagedmagnetEntityBase.php';

/**
 * This class has been auto-generated by Setforms
 * 
 * @package Entity
 * 
 * @author  cristianesantos
 */
class FpaCagedmagnetEntity extends FpaCagedmagnetEntityBase
{


    /**
     * Retorna registros.
     *
     * @param TkDateTime $mesCompetencia Mes de competencia.
     * @param integer    $nrOrg          Numero da organizacao.
     *
     * @return array FpacagedmagnetEntity
     *
     * @author thalesvalias - 23/05/2012
     */
    public function retornaRegistros(TkDateTime $mesCompetencia, $nrOrg){
        return Fpacagedmagnet::retornaRegistros($mesCompetencia, $nrOrg);
    }


    /**
     * Cria lista de objetos FpacagedmagnetEntity conforme array de tipo de registros.
     *
     * @param string $mesCompetencia    Mes de competencia.
     * @param string $listaTipoRegistro Lista com os tipos de registros.
     * @param string $nrOrg             Numero da Organizacao.
     *
     * @return boolean
     *
     * @author thalesvalias - 23/05/2012
     */
    public function inicializaListaRegistros($mesCompetencia, $listaTipoRegistro, $nrOrg){
        $resultados = Fpacagedmagnet::retornaRegistrosPorTipo($mesCompetencia, $listaTipoRegistro, $nrOrg);
        if (is_array($resultados) === true) {
            foreach ($resultados as $resultado) {
                $this->addItem($resultado, $resultado->getNrcagedmagnet());
            }

            return true;
        } else {
            return false;
        }
    }


    /**
     * Adiciona registro na lista.
     *
     * @param string $nrOrg                Numero da Organizacao.
     * @param string $mesCompetencia       Mes de competencia.
     * @param string $tipoRegistro         Numero do tipo de registro.
     * @param string $tipoInscricao        Numero do tipo de inscricao.
     * @param string $nrInscricao          Numero da inscricao.
     * @param string $linha                Linha do registro CAGED.
     * @param string $nrVinculo            Numero do vinculo.
     * @param string $dtAdmissao           Data de Admissao.
     * @param string $nrPisPasepCi         Numero de inscricao PIS / PASEP / CI.
     *
     * @return void
     *
     * @author thalesvalias - 23/05/2012
     */
    public function insereRegistroLista(
        $nrOrg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao, $linha,
        $nrVinculo = null, $dtAdmissao = null, $nrPisPasepCi = "0", $qtVincativos = null
    ){

        $item = new self();

        $item->setIdativo('S'); // Verificar.
        $item->setNrorg($nrOrg);
        $item->setMescompetencia($mesCompetencia);
        $item->setIdtiporegistro($tipoRegistro);
        $item->setIdtpinscestrutu($tipoInscricao);
        $item->setCdinscestrut($nrInscricao);
        $item->setDslinharegistro($linha);

        $item->setNrvinculom($nrVinculo);
        $item->setDtadmissaovinc($dtAdmissao);
        $item->setNrpispaseppes($nrPisPasepCi);
        $item->setQtvincativos($qtVincativos);

        $this->addItem($item);

    }


    /**
     * Insere ou atualiza registro.
     *
     * @param string $nrOrg            Numero da organizacao.
     * @param string $mesCompetencia   Mes de competencia.
     * @param string $tipoRegistro     Tipo de registro CAGED.
     * @param string $tipoInscricao    Tipo de inscricao.
     * @param string $nrInscricao      Numero de inscricao.
     * @param string $linha            Linha do registro.
     * @param string $nrVinculoM       Numero do vinculo.
     * @param string $dataAdmissao     Data de admissao do vinculo.
     * @param string $nrPisPasepCi     Numero de inscricao (PIS/PASEP/CI).
     * @param string $tipoMovimentacao Tipo de movimentacao de transferencia (legal/gerencial).
     *
     * @return void
     *
     * @author thalesvalias - 23/05/2012
     */
    public function persisteRegistro(
        $nrOrg, $mesCompetencia, $tipoRegistro, $tipoInscricao, $nrInscricao,
        $linha, $nrVinculoM, $dataAdmissao, $nrPisPasepCi, $tipoMovimentacao, $dtRescisaovinc
    ){
        // Procura o registro na base.
        $item = Fpacagedmagnet::retornaRegistrosTrabalhador(
            $mesCompetencia, $nrOrg, $tipoRegistro, $tipoInscricao, $nrInscricao, $nrPisPasepCi, $dataAdmissao, $tipoMovimentacao
        );

        if (is_object($item) === true) {
            $item->setNrcagedmagnet($item->getNrcagedmagnet());
            $item->setDslinharegistro($linha);
            //$item->getDtultatu(now());
        } else {
            $item = new self();

            $item->setIdativo('S'); // Verificar.
            $item->setNrorg($nrOrg);
            $item->setMescompetencia($mesCompetencia);
            $item->setIdtiporegistro($tipoRegistro);
            $item->setIdtpinscestrutu($tipoInscricao);
            $item->setCdinscestrut($nrInscricao);
            $item->setNrvinculom($nrVinculoM);
            $item->setDtadmissaovinc($dataAdmissao);
            $item->setNrpispaseppes($nrPisPasepCi);
            $item->setDslinharegistro($linha);
            $item->setNrtpmovtransfm($tipoMovimentacao);
            $item->setDtrescisaovinc($dtRescisaovinc);
        }

        $item->persist();
    }


    /**
     * Procura registro na lista.
     *
     * @param string $nrInscricao    Numero da inscricao da empresa.
     * @param string $tpRegistro     Numero do tipo do registro.
     *
     * @return boolean
     *
     * @author thalesvalias - 23/05/2012
     */
    public function procuraRegistroLista($nrInscricao, $tpRegistro) {
        $itens = $this->getItems();
        foreach ($itens as $key => $item) {
            if (($item->getCdinscestrut() === (string)$nrInscricao)
                && ($item->getIdtiporegistro() === (string)$tpRegistro)
            ) {
                return $key;
            }
        }

        return false;
    }


    /**
     * Remove todos os registros da Org. no mes de competencia.
     *
     * @param integer $nrOrg          Numero da Organizacao.
     * @param string  $mesCompetencia Mes de competencia.
     *
     * @return void
     *
     * @author thalesvalias - 23/05/2012
     */
    public function retroceder($nrOrg, $mesCompetencia){

        $registros = $this->retornaRegistros($mesCompetencia, $nrOrg);
        if (count($registros) > 0) {
            foreach ($registros as $registro) {
                $this->addItem($registro);
                $this->removeItem($registro);
            }

            $this->persist();
        }
    }


    /**
     * Retorna o total de registros de acordo com o tipo de registro informado.
     *
     * @param string  $mesCompetencia Mes de competencia.
     * @param integer $nrOrg          Numero da organizacao.
     * @param integer $tipoRegistro   Tipo do registro.
     *
     * @return number
     *
     * @author thalesvalias 03/06/2012
     */
    public function totalRegistrosPorTipo($mesCompetencia, $nrOrg, $tipoRegistro){
        $totalRegistros = FpaCagedmagnet::totalRegistrosPorTipo($mesCompetencia, $nrOrg, $tipoRegistro);

        if (empty($totalRegistros) === false){
            $total = end(end($totalRegistros));
        }

        return $total;
    }


}